#
# spec file for package uperf
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uperf
Version:        1.0.8
Release:        1.4
Summary:        Unified Network Performance Tool
License:        GPL-3.0-only
Group:          Productivity/Networking/Diagnostic
URL:            http://www.uperf.org/
Source0:        https://github.com/uperf/uperf/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  lksctp-tools-devel
BuildRequires:  openssl-devel

%description
uperf is a network performance tool that supports modelling and replay of
various networking patterns. uperf was developed by the Performance
Applications Engineering group at Sun Microsystems and is released under the
GNU General Public License Version 3.

uperf represents the next generation benchmarking tools (like filebench) where
instead of running a fixed benchmark or workload, a description (or model) of
the workload is provided and the tool generates the load according to the
model. By distilling the benchmark or workload into a model, you can now do
various things like change the scale of the workload, change different
parameters, change protocols, etc and analyse the effect of these changes on
your model. You can also study the effect of interleaving CPU activity, or
think times or the use of SSL instead of TCP among many other things.

Some of the questions you could answer using uperf are
* Bandwidth and latency (unidirectional and bi-directional) with different
  protocols like TCP, UDP, SCTP, SSL
* Connection setup and teardown scalability for different protocols
* Effect of noise on ongoing network connections
* Does it matter if I use processes instead of threads to do network
  communication?
* What is the L2 cache miss rate for connection setup?
* Understand TCP, UDP, SCTP, SSL performance under a variety of conditions
and much more!

%prep
%autosetup

%build
autoreconf --install
%configure \
  --datadir="%{_datadir}/%{name}" \
  --enable-cpc \
  --enable-netstat \
  --enable-udp \
  --enable-ssl \
  --enable-sctp
%make_build

%install
%make_install
chmod 0644 AUTHORS ChangeLog COPYING NEWS README *.pem

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/uperf
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.xml

%changelog
* Fri Dec 29 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 1.0.8:
  * Add AF_VSOCK support
  * Fixed minor memory leak
  * Build system upkeep
* Wed May  6 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.0.7 (no changelog)
- Remove uperf-openssl-1_1.patch
- Remove reproducible.patch
* Mon Jun 10 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date
  to make package build reproducible (boo#1047218)
* Fri Mar  9 2018 mpluskal@suse.com
- Update to version 1.0.6:
  * No upstream changelog available
* Thu Dec 28 2017 crrodriguez@opensuse.org
- uperf-openssl-1_1.patch: fix build against openssl 1.1
* Fri Mar 24 2017 mpluskal@suse.com
- Update to version 1.0.5:
  * No upstream changelog available
- Drop no longer needed patches:
  * uperf-parse-fix-buffer-overflow.patch
  * uperf-1.0.4-dso.patch
- Small packaging cleanups
* Sat Apr  4 2015 mpluskal@suse.com
- Update to version 1.0.4
  * See Changelog for details
- Cleanup spec file with spec-cleaner
- Use url for source
- Remove uperf-fix_missing_printf_parameter.patch
- Add uperf-1.0.4-dso.patch
* Fri Jul 23 2010 pascal.bleser@opensuse.org
- update to 1.0.3
* Sat May 10 2008 guru@unixtech.be
- new package
